/* ------------------------------------------------------------------------- *
 * Copyright 2002-2021, OpenNebula Project, OpenNebula Systems               *
 *                                                                           *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may   *
 * not use this file except in compliance with the License. You may obtain   *
 * a copy of the License at                                                  *
 *                                                                           *
 * http://www.apache.org/licenses/LICENSE-2.0                                *
 *                                                                           *
 * Unless required by applicable law or agreed to in writing, software       *
 * distributed under the License is distributed on an "AS IS" BASIS,         *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  *
 * See the License for the specific language governing permissions and       *
 * limitations under the License.                                            *
 * ------------------------------------------------------------------------- */
import { memo } from 'react'
import PropTypes from 'prop-types'

import { Typography, lighten, darken } from '@mui/material'
import makeStyles from '@mui/styles/makeStyles'

import { addOpacityToColor } from 'client/utils'
import { SCHEMES } from 'client/constants'

const useStyles = makeStyles(({ spacing, palette, typography }) => {
  const getBackgroundColor = palette.mode === SCHEMES.DARK ? lighten : darken
  const defaultStateColor = palette.grey[palette.mode === SCHEMES.DARK ? 300 : 700]

  return {
    root: ({ stateColor = defaultStateColor }) => {
      const paletteColor = palette[stateColor]

      const color = paletteColor?.contrastText ?? getBackgroundColor(stateColor, 0.75)
      const bgColor = paletteColor?.dark ?? stateColor

      return {
        color,
        backgroundColor: addOpacityToColor(bgColor, 0.2),
        cursor: 'default',
        padding: spacing('0.25rem', '0.5rem'),
        borderRadius: 2,
        textTransform: 'uppercase',
        fontSize: typography.overline.fontSize,
        fontWeight: 500,
        lineHeight: 'normal'
      }
    }
  }
})

const StatusChip = memo(({ stateColor, text = '', ...props }) => {
  const classes = useStyles({ stateColor })

  return (
    <Typography component='span' className={classes.root} {...props}>
      {text}
    </Typography>
  )
},
(prev, next) =>
  prev.stateColor === next.stateColor &&
  prev.text === next.text
)

StatusChip.propTypes = {
  stateColor: PropTypes.string,
  text: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.node
  ])
}

StatusChip.displayName = 'StatusChip'

export default StatusChip
