/* ------------------------------------------------------------------------- *
 * Copyright 2002-2021, OpenNebula Project, OpenNebula Systems               *
 *                                                                           *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may   *
 * not use this file except in compliance with the License. You may obtain   *
 * a copy of the License at                                                  *
 *                                                                           *
 * http://www.apache.org/licenses/LICENSE-2.0                                *
 *                                                                           *
 * Unless required by applicable law or agreed to in writing, software       *
 * distributed under the License is distributed on an "AS IS" BASIS,         *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  *
 * See the License for the specific language governing permissions and       *
 * limitations under the License.                                            *
 * ------------------------------------------------------------------------- */
import * as yup from 'yup'
import { T, INPUT_TYPES, SCHEMES, DEFAULT_SCHEME, DEFAULT_LANGUAGE } from 'client/constants'
import { getValidationFromFields } from 'client/utils'

const SCHEME = {
  name: 'scheme',
  label: T.Schema,
  type: INPUT_TYPES.SELECT,
  values: [
    { text: T.System, value: SCHEMES.SYSTEM },
    { text: T.Dark, value: SCHEMES.DARK },
    { text: T.Light, value: SCHEMES.LIGHT }
  ],
  validation: yup
    .string()
    .trim()
    .required('Scheme field is required')
    .default(DEFAULT_SCHEME),
  grid: { md: 12 }
}

const LANGUAGES = {
  name: 'lang',
  label: T.Language,
  type: INPUT_TYPES.SELECT,
  values: () =>
    window?.langs?.map(({ key, value }) => ({ text: value, value: key })) ?? [],
  validation: yup
    .string()
    .trim()
    .required('Language field is required')
    .default(DEFAULT_LANGUAGE),
  grid: { md: 12 }
}

const DISABLE_ANIMATIONS = {
  name: 'disableanimations',
  label: T.DisableDashboardAnimations,
  type: INPUT_TYPES.CHECKBOX,
  validation: yup
    .boolean()
    .transform(value => {
      if (typeof value === 'boolean') return value

      return String(value).toUpperCase() === 'YES'
    })
    .default(false),
  grid: { md: 12 }
}

export const FORM_FIELDS = [SCHEME, LANGUAGES, DISABLE_ANIMATIONS]

export const FORM_SCHEMA = yup.object(
  getValidationFromFields(FORM_FIELDS)
)
